freeman_tukey

Function freeman_tukey 

pub fn freeman_tukey(
    lambda: f64,
    observed: &Array2<f64>,
    row_sums: &Array1<f64>,
    col_times_total: &Array1<f64>,
) -> Result<f64>
Errors

Returns an error if an expected frequency evaluates to zero, or if the calculated statistic results in a mathematically impossible value.