g_test

Function g_test 

pub fn g_test(
    observed: &Array2<f64>,
    row_sums: &Array1<f64>,
    col_times_total: &Array1<f64>,
    ln_total: f64,
    ln_row_sums: &Array1<f64>,
    ln_col_sums: &Array1<f64>,
) -> Result<f64>
Errors

Returns an error if an expected frequency evaluates to zero, or if the calculated statistic results in a mathematically impossible value.