pub trait CITest: Send + Sync {
// Required methods
fn run_test(
&self,
x_values: Array1<f64>,
y_values: Array1<f64>,
z: Array2<f64>,
) -> Result<TestResult>;
fn data_types(&self) -> &'static [CITestDataType];
}Expand description
Trait defining the interface for conditional independence tests.
All statistical tests for conditional independence must implement this trait to be compatible with the registry system.
Required Methods
Sourcefn run_test(
&self,
x_values: Array1<f64>,
y_values: Array1<f64>,
z: Array2<f64>,
) -> Result<TestResult>
fn run_test( &self, x_values: Array1<f64>, y_values: Array1<f64>, z: Array2<f64>, ) -> Result<TestResult>
Runs a conditional independence test on the given data.
Errors
Returns an error if the test computation fails (e.g., invalid input dimensions or numerical issues).
Sourcefn data_types(&self) -> &'static [CITestDataType]
fn data_types(&self) -> &'static [CITestDataType]
Data types that a test supports.